@@ -9,6 +9,7 @@ import lxml
 import re
 import xml2rfc.log
 import xml2rfc.utils
+
 try:
     import debug
     assert debug
@@ -303,11 +304,12 @@ class BaseRfcWriter:
         self.ascii = False
         self.nbws_cond = u'\u00A0'
         self.eref_list = []
+        self.xmlrfc = xmlrfc
+        self.pis = self.xmlrfc.getpis()
 
         # We will refer to the XmlRfc document root as 'r'
         self.xmlrfc = xmlrfc
         self.r = xmlrfc.getroot()
-        self.pis = xmlrfc.getpis()
 
         # Document counters
         self.ref_start = 1              # Start of reference counters
@@ -447,6 +449,9 @@ class BaseRfcWriter:
             initials = ". ".join(initials_list) + "."
         return initials
 
+    def parse_pi(self, pi):
+        return xml2rfc.utils.parse_pi(pi, self.pis)
+
     def _getTocIndex(self):
         return [item for item in self._index if item.toc]
         
@@ -483,7 +488,7 @@ class BaseRfcWriter:
                     if date.attrib['day'][0] == '0':
                         date.attrib['day'] = today.strftime('%d').replace('0', '')
             elif year != str(today.year) and not month:
-                xml2rfc.log.warn("Incomplete and out-of date <date/> element: %s" % lxml.etree.tostring(date))
+                xml2rfc.log.error("Incomplete and out-of date <date/> element: %s" % lxml.etree.tostring(date))
         try:
             datetime.datetime.strptime(date.attrib.get('year')+date.attrib.get('month'), '%Y%B')
         except ValueError:
@@ -491,6 +496,8 @@ class BaseRfcWriter:
                 datetime.datetime.strptime(date.attrib.get('year')+date.attrib.get('month'), '%Y%b')
             except ValueError:
                 xml2rfc.log.warn("Year and/or month are incorrect values in <date/> element: %s" % lxml.etree.tostring(date))
+        except TypeError:
+            pass
 
         # Setup the expiration string for drafts as published date + six months
         if self.draft:
@@ -845,9 +852,9 @@ class BaseRfcWriter:
         for element in section:
             # Check for a PI
             if element.tag is lxml.etree.PI:
-                pis = self.xmlrfc.parse_pi(element)
-                if pis and "needLines" in pis:
-                    self.needLines(pis["needLines"])
+                pidict = self.parse_pi(element)
+                if pidict and "needLines" in pidict:
+                    self.needLines(pidict["needLines"])
             # Write elements in XML document order
             if element.tag == 't':
                 anchor = element.attrib.get('anchor')
@@ -1013,6 +1020,14 @@ class BaseRfcWriter:
         self.figure_count = 0
         self.table_count = 0
         self.eref_count = 0
+        self.pis = self.xmlrfc.getpis()
+
+        # Abstract
+        abstract = self.r.find('front/abstract')
+        if abstract is not None:
+            self.write_heading('Abstract', autoAnchor='rfc.abstract')
+            for t in abstract.findall('t'):
+                self.write_t_rec(t)
 
         # Middle sections
         middle = self.r.find('middle')
@@ -1081,6 +1096,7 @@ class BaseRfcWriter:
         self.figure_count = 0
         self.table_count = 0
         self.eref_count = 0
+        self.pis = self.xmlrfc.getpis()
 
         # Block header
         topblock = self.pis['topblock']
